--- busybox-0.60.5/usage.h.alt-raidautorun	2002-10-01 00:59:58 +0400
+++ busybox-0.60.5/usage.h	2003-07-09 15:33:46 +0400
@@ -1366,6 +1366,15 @@
 	"$ pwd\n" \
 	"/root\n"
 
+#define raidautorun_trivial_usage \
+	"[DEVICE]"
+#define raidautorun_full_usage \
+	"Start all autodetected Software-RAID devices.\n"
+	"\n"
+	"DEVICE is used only for communication with the kernel RAID driver -\n"
+	"all detected devices are started, not only the one specified.\n"
+	"If DEVICE is omitted, /dev/md0 is used."
+
 #define rdate_trivial_usage \
 	"[OPTION] HOST"
 #define rdate_full_usage \
--- busybox-0.60.5/applets.h.alt-raidautorun	2002-09-18 02:04:28 +0400
+++ busybox-0.60.5/applets.h	2003-07-09 15:33:46 +0400
@@ -320,6 +320,9 @@
 #ifdef BB_PWD
 	APPLET(pwd, pwd_main, _BB_DIR_BIN)
 #endif
+#ifdef BB_RAIDAUTORUN
+	APPLET(raidautorun, raidautorun_main, _BB_DIR_SBIN)
+#endif
 #ifdef BB_RDATE
 	APPLET(rdate, rdate_main, _BB_DIR_USR_BIN)
 #endif
--- busybox-0.60.5/Config.h.alt-raidautorun	2003-07-09 15:33:46 +0400
+++ busybox-0.60.5/Config.h	2003-07-09 15:33:46 +0400
@@ -94,6 +94,7 @@
 //#define BB_PRINTF
 //#define BB_PS
 //#define BB_PWD
+#define BB_RAIDAUTORUN
 //#define BB_RDATE
 //#define BB_READLINK
 //#define BB_REBOOT
--- busybox-0.60.5/raidautorun.c.alt-raidautorun	2003-07-09 15:33:46 +0400
+++ busybox-0.60.5/raidautorun.c	2003-07-09 15:34:39 +0400
@@ -0,0 +1,64 @@
+/* vi: set sw=4 ts=4: */
+/*
+ * Mini raidautorun implementation for busybox
+ *
+ *
+ * Copyright (C) 2003 by Sergey Vlasov <vsu@altlinux.ru>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+ * 02111-1307 USA
+ *
+ */
+
+/* getopt not needed */
+
+#include <stdlib.h>
+#include <stdio.h>
+#include <string.h>
+#include <unistd.h>
+#include <fcntl.h>
+#include <sys/types.h>
+#include <sys/ioctl.h>
+
+#include <linux/major.h>
+#include <linux/raid/md_u.h>
+
+#include "busybox.h"
+
+
+int raidautorun_main(int argc, char **argv)
+{
+	const char *md_name;
+	int md_fd;
+
+	if (argc == 1) {
+		md_name = "/dev/md0";
+	} else if (argc == 2) {
+		md_name = argv[1];
+	} else {
+		show_usage();
+	}
+
+	md_fd = open(md_name, O_RDWR);
+	if (md_fd == -1) {
+		perror_msg_and_die("%s: open", md_name);
+	}
+
+	if (ioctl(md_fd, RAID_AUTORUN, 0L) == -1) {
+		perror_msg_and_die("%s: RAID_AUTORUN", md_name);
+	}
+
+	return EXIT_SUCCESS;
+}
